==> com.liferay.dynamic.data.mapping.form.builder-2.0.78.jar: META-INF/resources/js/components/LayoutProvider/handlers/fieldDeletedHandler.es.js <==
Liferay.Loader.define("dynamic-data-mapping-form-builder@2.0.78/js/components/LayoutProvider/handlers/fieldDeletedHandler.es", ['module', 'exports', 'require', 'dynamic-data-mapping-form-renderer/js/components/FormRenderer/FormSupport.es', 'dynamic-data-mapping-form-renderer/js/util/visitors.es', '../../RuleBuilder/RulesSupport.es'], function (module, exports, require) {
  var define = undefined;
  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = exports.handleFieldDeleted = void 0;

  var FormSupport = _interopRequireWildcard(require("dynamic-data-mapping-form-renderer/js/components/FormRenderer/FormSupport.es"));

  var _visitors = require("dynamic-data-mapping-form-renderer/js/util/visitors.es");

  var _RulesSupport = _interopRequireDefault(require("../../RuleBuilder/RulesSupport.es"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _getRequireWildcardCache() {
    if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
      return cache;
    };return cache;
  }

  function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
      return obj;
    }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
      return { "default": obj };
    }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
      return cache.get(obj);
    }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
      if (Object.prototype.hasOwnProperty.call(obj, key)) {
        var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
          Object.defineProperty(newObj, key, desc);
        } else {
          newObj[key] = obj[key];
        }
      }
    }newObj["default"] = obj;if (cache) {
      cache.set(obj, newObj);
    }return newObj;
  }

  function ownKeys(object, enumerableOnly) {
    var keys = Object.keys(object);if (Object.getOwnPropertySymbols) {
      var symbols = Object.getOwnPropertySymbols(object);if (enumerableOnly) symbols = symbols.filter(function (sym) {
        return Object.getOwnPropertyDescriptor(object, sym).enumerable;
      });keys.push.apply(keys, symbols);
    }return keys;
  }

  function _objectSpread(target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i] != null ? arguments[i] : {};if (i % 2) {
        ownKeys(Object(source), true).forEach(function (key) {
          _defineProperty(target, key, source[key]);
        });
      } else if (Object.getOwnPropertyDescriptors) {
        Object.defineProperties(target, Object.getOwnPropertyDescriptors(source));
      } else {
        ownKeys(Object(source)).forEach(function (key) {
          Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key));
        });
      }
    }return target;
  }

  function _defineProperty(obj, key, value) {
    if (key in obj) {
      Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true });
    } else {
      obj[key] = value;
    }return obj;
  }

  var formatRules = function formatRules(state, pages) {
    var visitor = new _visitors.PagesVisitor(pages);
    var rules = (state.rules || []).map(function (rule) {
      var actions = rule.actions,
          conditions = rule.conditions;
      conditions.forEach(function (condition) {
        var firstOperandFieldExists = false;
        var secondOperandFieldExists = false;
        var secondOperand = condition.operands[1];
        visitor.mapFields(function (_ref) {
          var fieldName = _ref.fieldName;

          if (condition.operands[0].value === fieldName) {
            firstOperandFieldExists = true;
          }

          if (secondOperand && secondOperand.value === fieldName) {
            secondOperandFieldExists = true;
          }
        });

        if (condition.operands[0].value === 'user') {
          firstOperandFieldExists = true;
        }

        if (!firstOperandFieldExists) {
          _RulesSupport["default"].clearAllConditionFieldValues(condition);
        }

        if (!secondOperandFieldExists && secondOperand && secondOperand.type == 'field') {
          _RulesSupport["default"].clearSecondOperandValue(condition);
        }
      });
      return _objectSpread({}, rule, {
        actions: _RulesSupport["default"].syncActions(pages, actions),
        conditions: conditions
      });
    });
    return rules;
  };

  var removeEmptyRow = function removeEmptyRow(pages, source) {
    var pageIndex = source.pageIndex,
        rowIndex = source.rowIndex;

    if (!FormSupport.rowHasFields(pages, pageIndex, rowIndex)) {
      pages = FormSupport.removeRow(pages, pageIndex, rowIndex);
    }

    return pages;
  };

  var handleFieldDeleted = function handleFieldDeleted(state, _ref2) {
    var indexes = _ref2.indexes;
    var columnIndex = indexes.columnIndex,
        pageIndex = indexes.pageIndex,
        rowIndex = indexes.rowIndex;
    var pages = state.pages;
    var newContext = FormSupport.removeFields(pages, pageIndex, rowIndex, columnIndex);
    newContext = removeEmptyRow(newContext, {
      columnIndex: columnIndex,
      pageIndex: pageIndex,
      rowIndex: rowIndex
    });
    return {
      focusedField: {},
      pages: newContext,
      rules: formatRules(state, newContext)
    };
  };

  exports.handleFieldDeleted = handleFieldDeleted;
  var _default = handleFieldDeleted;
  exports["default"] = _default;
  //# sourceMappingURL=fieldDeletedHandler.es.js.map
});
//# sourceMappingURL=fieldDeletedHandler.es.js.map

==> com.liferay.dynamic.data.mapping.form.builder-2.0.81.jar: META-INF/resources/js/components/LayoutProvider/handlers/fieldDeletedHandler.es.js <==
Liferay.Loader.define("dynamic-data-mapping-form-builder@2.0.81/js/components/LayoutProvider/handlers/fieldDeletedHandler.es", ['module', 'exports', 'require', 'dynamic-data-mapping-form-renderer/js/components/FormRenderer/FormSupport.es', '../../RuleBuilder/RulesSupport.es'], function (module, exports, require) {
  var define = undefined;
  function _typeof(obj) {
    "@babel/helpers - typeof";
    if (typeof Symbol === "function" && typeof Symbol.iterator === "symbol") {
      _typeof = function _typeof(obj) {
        return typeof obj;
      };
    } else {
      _typeof = function _typeof(obj) {
        return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj;
      };
    }return _typeof(obj);
  }

  Object.defineProperty(exports, "__esModule", {
    value: true
  });
  exports["default"] = exports.handleFieldDeleted = void 0;

  var FormSupport = _interopRequireWildcard(require("dynamic-data-mapping-form-renderer/js/components/FormRenderer/FormSupport.es"));

  var _RulesSupport = _interopRequireDefault(require("../../RuleBuilder/RulesSupport.es"));

  function _interopRequireDefault(obj) {
    return obj && obj.__esModule ? obj : { "default": obj };
  }

  function _getRequireWildcardCache() {
    if (typeof WeakMap !== "function") return null;var cache = new WeakMap();_getRequireWildcardCache = function _getRequireWildcardCache() {
      return cache;
    };return cache;
  }

  function _interopRequireWildcard(obj) {
    if (obj && obj.__esModule) {
      return obj;
    }if (obj === null || _typeof(obj) !== "object" && typeof obj !== "function") {
      return { "default": obj };
    }var cache = _getRequireWildcardCache();if (cache && cache.has(obj)) {
      return cache.get(obj);
    }var newObj = {};var hasPropertyDescriptor = Object.defineProperty && Object.getOwnPropertyDescriptor;for (var key in obj) {
      if (Object.prototype.hasOwnProperty.call(obj, key)) {
        var desc = hasPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : null;if (desc && (desc.get || desc.set)) {
          Object.defineProperty(newObj, key, desc);
        } else {
          newObj[key] = obj[key];
        }
      }
    }newObj["default"] = obj;if (cache) {
      cache.set(obj, newObj);
    }return newObj;
  }

  /**
   * Copyright (c) 2000-present Liferay, Inc. All rights reserved.
   *
   * This library is free software; you can redistribute it and/or modify it under
   * the terms of the GNU Lesser General Public License as published by the Free
   * Software Foundation; either version 2.1 of the License, or (at your option)
   * any later version.
   *
   * This library is distributed in the hope that it will be useful, but WITHOUT
   * ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS
   * FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License for more
   * details.
   */
  var removeEmptyRow = function removeEmptyRow(pages, source) {
    var pageIndex = source.pageIndex,
        rowIndex = source.rowIndex;

    if (!FormSupport.rowHasFields(pages, pageIndex, rowIndex)) {
      pages = FormSupport.removeRow(pages, pageIndex, rowIndex);
    }

    return pages;
  };

  var handleFieldDeleted = function handleFieldDeleted(state, _ref) {
    var indexes = _ref.indexes;
    var columnIndex = indexes.columnIndex,
        pageIndex = indexes.pageIndex,
        rowIndex = indexes.rowIndex;
    var pages = state.pages;
    var newContext = FormSupport.removeFields(pages, pageIndex, rowIndex, columnIndex);
    newContext = removeEmptyRow(newContext, {
      columnIndex: columnIndex,
      pageIndex: pageIndex,
      rowIndex: rowIndex
    });
    return {
      focusedField: {},
      pages: newContext,
      rules: _RulesSupport["default"].formatRules(newContext, state.rules)
    };
  };

  exports.handleFieldDeleted = handleFieldDeleted;
  var _default = handleFieldDeleted;
  exports["default"] = _default;
  //# sourceMappingURL=fieldDeletedHandler.es.js.map
});
//# sourceMappingURL=fieldDeletedHandler.es.js.map
